# image-upscaling.net API Client

A simple Python package to interact with the free [image-upscaling.net](https://image-upscaling.net/) API. This client provides two key functions for uploading images for processing and querying their processing status.

## Features

- **Upload Images**: Send images to the upscaling service with 3 enhancement options.
- **Query Status**: Retrieve the processing status of your images, categorized as waiting, completed, or in progress.

## Installation

Install the package using pip:

```bash
pip install image-upscaling-api
```

## Usage

### Uploading an Image

The `upload_image` function sends an image for upscaling.

Note: The `client_id` must be a 32-digit hexadecimal string of your choice to identify your requests.

```python
from image_upscaling_api import upload_image

# Example usage:
upload_image("r1.png", "481d40602d3f4570487432044df03a52", 
             use_repair_mode=False, 
             use_large_model=True, 
             use_face_enhance=False)
```

#### Parameters:
- `image_path` (str): Path to the image file.
- `client_id` (str): Your 32-digit hexadecimal client ID.
- `use_repair_mode` (bool): Enable to repair image details.
- `use_large_model` (bool): Enable to use a more robust upscaling model.
- `use_face_enhance` (bool): Enable to improve facial features.

### Querying Processing Status

The `get_uploaded_images` function retrieves the status of your uploaded images.

```python
from image_upscaling_api import get_uploaded_images

# Example usage:
waiting, completed, in_progress = get_uploaded_images("481d40602d3f4570487432044df03a52")
```

#### Returns:
- `waiting` (list): Images queued for processing.
- `completed` (list): Images that have been processed.
- `in_progress` (list): Images currently being processed.

## Support

If you find this project useful, please consider supporting it! 
[<img src="https://image-upscaling.net/assets/images/pypl_donate.png" width=200>](https://www.paypal.com/donate/?hosted_button_id=FTQ965QDJBUGY)

Discord: https://discord.gg/utXujgAT8R

## License

This project is licensed under the MIT License.